@@ -36,6 +36,7 @@
 #include "debugger_hd64180.h"
 #include "debugger_m680x0.h"
 #include "debugger_m88xx0.h"
+#include "ascii_ctype.h"
 #include "event.h"
 #include "hostcom.h"
 #include "mainapp.h"
@@ -1408,7 +1409,7 @@ Debugger::ParseCmdbuf()
 	for (;;) {
 		// 先頭の空白はスキップ
 		for (; cmdbuf[pos] != '\0'; pos++) {
-			if (!isspace((unsigned int)cmdbuf[pos]))
+			if (!is_ascii_space(cmdbuf[pos]))
 				break;
 		}
 		if (cmdbuf[pos] == '\0')
@@ -1417,7 +1418,7 @@ Debugger::ParseCmdbuf()
 		// 終わりを探す
 		start = pos;
 		for (; cmdbuf[pos] != '\0'; pos++) {
-			if (isspace((unsigned int)cmdbuf[pos]))
+			if (is_ascii_space(cmdbuf[pos]))
 				break;
 		}
 		cmdargs.push_back(cmdbuf.substr(start, pos - start));
@@ -2301,7 +2302,7 @@ Debugger::cmd_hist_common(BranchHistory& hist)
 	}
 
 	// 表示
-	MONITOR_UPDATE(histmon, screen);
+	histmon->Update(screen);
 	ShowTextScreen(screen);
 
 	return CmdAct::Stay;
@@ -2887,9 +2888,9 @@ Debugger::cmd_show()
 		}
 
 		// 一覧を表示
-		std::string msg = MonitorManager::MakeListString(list);
 		fprintf(cons, "Usage: show <monitor>\n");
-		fprintf(cons, "%s", msg.c_str());
+		std::vector<std::string> names = gMonitorManager->MakeListString(list);
+		MainApp::ShowHelpList(cons, names);
 		return CmdAct::Stay;
 	}
 
@@ -2948,7 +2949,7 @@ Debugger::ShowMonitor(Monitor *monitor)
 	auto size = monitor->GetSize();
 	ts.Init(size.width, size.height);
 
-	MONITOR_UPDATE(monitor, ts);
+	monitor->Update(ts);
 	ShowTextScreen(ts);
 }
 
