@@ -29,23 +29,24 @@ class VectorTable : public Device
 
 	bool Init() override;
 
-	// 例外名を返す (ベクタテーブル用)
-	const char *GetTableName(int vector) const;
-
 	// 例外名を返す (例外履歴用)
 	const char *GetExceptionName(int vector) const;
 
 	// ベクタテーブルの要素数を返す
 	int Size() const { return nametable.size(); }
 
-	// モニタ更新
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
-
  private:
 	// 初期化
 	void InitTableM680x0(VMType vmtype);
 	void InitTableLuna88k();
 
+	// モニタ更新
+	DECLARE_MONITOR_CALLBACK(MonitorUpdateM680x0);
+	DECLARE_MONITOR_CALLBACK(MonitorUpdateM88xx0);
+
+	// m88100 のベクタテーブルから再分岐先を取得する。
+	busaddr VectorToAddr(uint32 vecaddr);
+
 	// ベクタテーブル
 	std::vector<const char *> nametable {};
 
@@ -61,7 +62,7 @@ class VectorTable : public Device
 	static std::map<int, const char * const>   name_luna1;
 	static std::map<int, const char * const>   name_news;
 	static std::map<int, const char * const>   name_virt68k;
-	static std::array<const char * const, 11>  name_luna88k;
+	static std::map<int, const char * const>   name_luna88k;
 };
 
 static inline VectorTable *GetVectorTable() {
