@@ -18,6 +18,38 @@
 <div class="main1">
 <dl>
 
+<dt>1.6.0 (2025/10/29)
+<dd><ul>
+<li>host(New): サウンド出力を実装。<q>Implement sound output.</q>
+<li>vm(New): X68030 の ADPCM (再生側のみ) を実装。
+ <q>Implement ADPCM (playback only) on X68030.</q>
+<li>vm(Update): X68030 DMAC の外部要求転送を実装。
+ <q>Implement external request transfer on X68030 DMAC.</q>
+<li>vm(Update): X68030 DMAC のリンクアレイチェインモードを実装。
+ <q>Implement link array chain mode on X68030 DMAC.</q>
+<li>vm(Update): X68030 DMAC のログをチャンネルごとに分離。
+ <q>Separate loglevel per channel.</q>
+<li>vm(Update): Human68k モードの FPACK __LTOS を実装。
+ <q>Implement FPACK __LTOS on Human68k mode.</q>
+<li>GUI(New): スレッドモニタを実装。
+ <q>Implement thread monitor.</q>
+<li>app(New): ヘテロジニアス構成 CPU のコアの指定に (正式に) 対応。
+ <q>Support specifying cores for heterogeneous CPU (formally).</q>
+<li>vm(Fix): X68030 もキー押下で高速モードを抑制するように戻す。
+ver 1.5.0 で廃止したが副作用があったため。
+ <q>Revert to suppressing full speed mode on key press on X68030.
+ It was removed in ver 1.5.0, but was reintroduced
+ to address unintended side effects.</q>
+<li>host(Update): 設定項目 <tt>host-avx2</tt>, <tt>host-neon</tt> を
+ <tt>hostcpu-avx2</tt>, <tt>hostcpu-neon</tt> にリネーム。
+ <q><tt>host-avx2</tt>, <tt>host-neon</tt> are renamed to
+ <tt>hostcpu-avx2</tt>, <tt>hostcpu-neon</tt>.</q>
+<li>app(Fix): NetBSD 11.0_BETA で設定ファイルに非 ASCII
+ 文字があると不正終了する場合があったのを修正。
+ <q>Fix possible abnormal termination if the configuration file contains
+ non-ASCII characters on NetBSD 11.0_BETA.</q>
+</ul><p>
+
 <dt>1.5.0 (2025/09/07)
 <dd><ul>
 <li>vm(New): X68030 のグラフィック画面を 1024x1024 モードのみ簡易実装。
