@@ -12,7 +12,7 @@
 #include "hostdevice.h"
 
 // コンストラクタ
-Driver::Driver(HostDevice *hostdev_, const char *drivername_)
+Driver::Driver(HostDevice *hostdev_, const std::string& drivername_)
 	: inherited(OBJ_NONE)
 {
 	hostdev = hostdev_;
