@@ -140,7 +140,7 @@ class HostNetDevice : public HostDevice
 	void SetMCastFilter(uint64 filter);
 
 	// ドライバ名を返す。
-	const std::string GetDriverName();
+	const std::string& GetDriverName();
 
 	// 統計情報を返す (ステータスパネルから呼ばれる)
 	uint64 GetTXPkts() const { return stat.tx_pkts; }
@@ -152,6 +152,9 @@ class HostNetDevice : public HostDevice
 	// コンパイル済みのドライバ名一覧を返す
 	static std::vector<std::string> GetDrivers();
 
+	// libslirp のバージョン文字列を返す
+	static const char *GetSlirpVersion();
+
 	// デバッグ用。
 	static std::vector<std::string> DumpHex(const void *, size_t);
 	static std::vector<std::string> DumpFrame(const void *, size_t);
