@@ -9,6 +9,7 @@
 //
 
 #include "hostwindrv.h"
+#include "ascii_ctype.h"
 #include <dirent.h>
 #include <inttypes.h>
 #include <fcntl.h>
@@ -390,7 +391,7 @@ HostWindrv::IsHuman68kFilename(const char *fname) const
 
 	for (auto c : name) {
 		// TODO: 記号どこまで使えるか調べる
-		if (!isalnum((int)c) && strchr("-._", c) == NULL) {
+		if (!is_ascii_alnum(c) && strchr("-._", c) == NULL) {
 			return false;
 		}
 	}
