@@ -19,7 +19,7 @@ class NetDriverTap : public NetDriver
 	NetDriverTap(HostDevice *hostdev_, const std::string& devpath_);
 	~NetDriverTap() override;
 
-	bool InitDriver() override;
+	bool InitDriver(bool startup) override;
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
 
