@@ -518,18 +518,17 @@ BitmapRGBX::DrawBitmapI8Scale(const Rect& dr, const BitmapI8& src,
 	}
 }
 
-// (dx, dy) にビットマップ(RGBX) src を描画する。
+// (dx, dy) にビットマップ(RGBX) src の範囲 sr を描画する。
 // 描画範囲をはみ出さないこと。
 void
-BitmapRGBX::DrawBitmap(int dx, int dy, const BitmapRGBX& src)
+BitmapRGBX::DrawBitmap(int dx, int dy, const BitmapRGBX& src, const Rect& sr)
 {
 	assert(buf);
 
-	const uint32 *s = (const uint32 *)src.GetBuf();
-
-	for (uint y = 0; y < src.GetHeight(); y++) {
+	for (uint y = 0; y < sr.h; y++) {
 		uint32 *d = (uint32 *)GetPtr(dx, dy + y);
-		for (uint x = 0; x < src.GetWidth(); x++) {
+		const uint32 *s = (const uint32 *)src.GetPtr(sr.x, sr.y + y);
+		for (uint x = 0; x < sr.w; x++) {
 			*d++ = *s++;
 		}
 	}
