@@ -23,6 +23,7 @@
 #include "vm_x68k.h"
 #include <getopt.h>
 #include <pwd.h>
+#include <sys/ioctl.h>
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <algorithm>
@@ -31,6 +32,8 @@
 #include <sys/prctl.h>
 #endif
 
+static std::string maptocsv(const std::vector<bool>& list);
+
 // グローバルインスタンス
 MainApp gMainApp;
 
@@ -202,6 +205,12 @@ MainApp::Init1a(int ac, char *av[], std::string (*conv)(const std::string&))
 		return rv;
 	}
 
+	// スレッドマネージャ (ログより前)
+	threadmanager.reset(new ThreadManager());
+	// ここでメインスレッド関連の設定。
+	PTHREAD_SETNAME("Main");
+	threadmanager->RegistThread(NULL, "Main");
+
 	// モニタマネージャ (VM 作成より前、もしかしたら Config より前?)
 	pMonitorManager.reset(new MonitorManager());
 	gMonitorManager = pMonitorManager.get();
@@ -287,6 +296,10 @@ MainApp::Init1a(int ac, char *av[], std::string (*conv)(const std::string&))
 	// ログ表示のためだけのオブジェクト
 	hostcpu.reset(new Object(OBJ_HOSTCPU));
 
+	// この後の CheckCPU() で hostcpu のログを出したいので、
+	// 先にログレベルを分かる分だけ処理する。
+	ParseLogoptEarly();
+
 	// ホスト CPU の機能チェック。
 	if (CheckCPU() == false) {
 		return EXIT_FAILURE;
@@ -378,6 +391,16 @@ MainApp::Init1b()
 		return EXIT_SUCCESS;
 	}
 
+	// 古い隠しオプションは書式に互換性がないので捨てる。
+	// --show-config の後にしないといけない。
+	const ConfigItem& item_cpu_aff = gConfig->Find(".host-cpu-affinity");
+	if (item_cpu_aff.GetFrom() != ConfigItem::FromInitial) {
+		item_cpu_aff.Err(
+			"Obsolete. Replace it with new syntax 'hostcpu-fastcore'. "
+			"(Please see document)");
+		return false;
+	}
+
 	// 4.2 ログレベルを設定。コンストラクト後すぐに行う。
 	// -L help もここで処理。
 	if (!ParseLogopt()) {
@@ -442,9 +465,6 @@ MainApp::Init2()
 		return false;
 	}
 
-	// メインスレッド名を設定
-	PTHREAD_SETNAME("Main");
-
 	// 8. スレッド開始
 	if (!pVM->StartThread()) {
 		return false;
@@ -707,54 +727,16 @@ MainApp::AbsPath(const char *path)
 bool
 MainApp::CheckCPU()
 {
-	const ConfigItem& item_aff = gConfig->Find(".host-cpu-affinity");
-	std::string cfg_aff = item_aff.AsString();
-
-	if (cfg_aff.empty() || cfg_aff == "auto") {
-		// 指定なし
-		// (auto も今の所指定なしと同じ)
-		cpu_affinity = CPUAffinity::None;
-	} else if (cfg_aff.find(':') == std::string::npos) {
-		item_aff.Err();
-	} else {
-		// 書式は "<key>:<list>"。
-		// <key> は "low", "high", "perf" のいずれか。
-		// <list> は "0,3-5,7" みたいな感じ。
-		std::vector<std::string> vals = string_split(cfg_aff, ':');
-		std::string key = string_trim(vals[0]);
-		std::string csv = vals[1];
-		if (key == "low") {
-			cpu_affinity = CPUAffinity::Low;
-		} else if (key == "high") {
-			cpu_affinity = CPUAffinity::High;
-		} else if (key == "perf") {
-			cpu_affinity = CPUAffinity::Perf;
-		} else {
-			item_aff.Err("Invalid affinity keyword");
-		}
-		cpu_list.resize(std::thread::hardware_concurrency());
-		auto errmsg = ParseCPUList(cpu_list, csv);
-		if (errmsg.empty() == false) {
-			item_aff.Err(errmsg);
-			return false;
-		}
-
-		// 全部 true/false なら、これは意味がないのでクリアする。
-		uint num = std::count(cpu_list.begin(), cpu_list.end(), true);
-		if (num == 0) {
-			item_aff.Err("No valid cores specified (Ignoring it)");
-			cpu_affinity = CPUAffinity::None;
-		} else if (num == cpu_list.size()) {
-			item_aff.Err("All cores specified (Ignoring it)");
-			cpu_affinity = CPUAffinity::None;
-		}
+	// ヘテロ構成とか。
+	if (CheckCPUAffinity() == false) {
+		return false;
 	}
 
 #if defined(HAVE_AVX2)
 	// AVX2
 	detect_avx2 = ::DetectAVX2();
 
-	const ConfigItem& item_avx2 = gConfig->Find("host-avx2");
+	const ConfigItem& item_avx2 = gConfig->Find("hostcpu-avx2");
 	std::string cfg_avx2 = item_avx2.AsString();
 
 	if (cfg_avx2 == "auto") {
@@ -771,7 +753,7 @@ MainApp::CheckCPU()
 	// NEON は aarch64 なら必ずある?
 	detect_neon = true;
 
-	const ConfigItem& item_neon = gConfig->Find("host-neon");
+	const ConfigItem& item_neon = gConfig->Find("hostcpu-neon");
 	std::string cfg_neon = item_neon.AsString();
 
 	if (cfg_neon == "auto") {
@@ -788,16 +770,76 @@ MainApp::CheckCPU()
 	return true;
 }
 
-// CPU 番号リストの文字列からビット配列を作って返す。
-// cpulist は CPU コア数で初期化(resize)しておくこと。
+// CPU アフィニティを調べる。
+// 成功なら affinity_policy (と fastcore) をセットして true を返す。
+// 失敗ならエラーを表示して false を返す。
+bool
+MainApp::CheckCPUAffinity()
+{
+	affinity_policy = AffinityPolicy::Neutral;
+	fastcore.resize(std::thread::hardware_concurrency());
+
+	const ConfigItem& item_aff = gConfig->Find("hostcpu-fastcore");
+	std::string cfg_aff = item_aff.AsString();
+
+	if (cfg_aff == "none") {
+		// 何もしない。
+
+	} else if (cfg_aff == "auto") {
+#if defined(__x86_64__)
+		if (ThreadManager::DetectCPUAffinity_x86(fastcore) == false) {
+			// 自動認識に失敗しただけなので、なかったことにして進む。
+			std::fill(fastcore.begin(), fastcore.end(), false);
+		}
+
+		// 区別出来た時だけ Binding にする。
+		uint num = std::count(fastcore.begin(), fastcore.end(), true);
+		if (num != 0 && num != fastcore.size()) {
+			affinity_policy = AffinityPolicy::Binding;
+		}
+#else
+		// none と同じ。
+#endif
+
+	} else {
+		// 手動設定。
+		// "0,3-5,7" みたいな感じで高性能側 CPU の番号を列挙。
+		affinity_policy = AffinityPolicy::Binding;
+		auto errmsg = ParseCPUList(cfg_aff);
+		if (errmsg.empty() == false) {
+			item_aff.Err(errmsg);
+			return false;
+		}
+
+		uint num = std::count(fastcore.begin(), fastcore.end(), true);
+		if (num == 0 || num == fastcore.size()) {
+			// 区別がないとたぶん割り当て出来ないスレッドが出来てしまうので
+			// エラーにする?
+			item_aff.Err("All cores have the same affinity?");
+			return false;
+		}
+	}
+
+	if (hostcpu->loglevel >= 1) {
+		if (affinity_policy == AffinityPolicy::Neutral) {
+			hostcpu->putmsgn("%s: affinity_policy=neutral", __func__);
+		} else {
+			hostcpu->putmsgn("%s: affinity_policy=binding", __func__);
+			hostcpu->putmsgn("%s: fast_cores=%s", __func__,
+				maptocsv(fastcore).c_str());
+		}
+	}
+
+	return true;
+}
+
+// CPU 番号リストの文字列からビット配列を作って fastcore にセットする。
+// fastcore は事前にコア数分確保してあること。
 // 成功すれば string.empty を返す。
 // 失敗すればエラーメッセージを返す。
 std::string
-MainApp::ParseCPUList(std::vector<bool>& cpulist, const std::string& input)
+MainApp::ParseCPUList(const std::string& input)
 {
-	if (input.empty()) {
-		return "<cpulist> must be specified";
-	}
 
 	// 設定は "0,3-5,7,10-" のような書式
 	std::vector<std::string> csv = string_split(input, ',');
@@ -827,7 +869,7 @@ MainApp::ParseCPUList(std::vector<bool>& cpulist, const std::string& input)
 				return "syntax error";
 			}
 			start = 0;
-		} else if (r[r.size() - 1] == '-') {
+		} else if (r.back() == '-') {
 			// "a-" なら範囲 [a, MAX]
 			str = &r[0];
 			errno = 0;
@@ -835,7 +877,7 @@ MainApp::ParseCPUList(std::vector<bool>& cpulist, const std::string& input)
 			if (endp == str || endp != &r[r.size() - 1] || errno == ERANGE) {
 				return "syntax error";
 			}
-			last = cpulist.size();
+			last = fastcore.size() - 1;
 		} else {
 			// "a-b" なら範囲 [a, b]
 			str = &r[0];
@@ -858,22 +900,56 @@ MainApp::ParseCPUList(std::vector<bool>& cpulist, const std::string& input)
 			}
 		}
 
-		if (start >= cpulist.size()) {
+		if (start >= fastcore.size()) {
 			return string_format("cpu number %u exceeds number of cores(%zu)",
-				start, cpulist.size());
+				start, fastcore.size());
 		}
-		if (last >= cpulist.size()) {
+		if (last >= fastcore.size()) {
 			return string_format("cpu number %u exceeds number of cores(%zu)",
-				start, cpulist.size());
+				last, fastcore.size());
 		}
 		for (uint n = start; n <= last; n++) {
-			cpulist[n] = true;
+			fastcore[n] = true;
 		}
 	}
 
 	return "";
 }
 
+// srclist を "0-8,10" みたいな可読文字列にする。
+static std::string
+maptocsv(const std::vector<bool>& srclist)
+{
+	std::string rv;
+	int start = -1;
+
+	// 最後が true で終わっている場合の処理分けを減らすため、
+	// 末尾に false を足しておく。
+	std::vector<bool> list = srclist;
+	list.push_back(false);
+
+	for (uint i = 0; i < list.size(); i++) {
+		if (start == -1) {
+			if (list[i] == true) {
+				if (rv.size() != 0) {
+					rv += ',';
+				}
+				rv += string_format("%u", i);
+				start = i;
+			}
+		} else {
+			if (list[i] == false) {
+				int end = i - 1;
+				if (start < end) {
+					rv += string_format("-%u", end);
+				}
+				start = -1;
+			}
+		}
+	}
+	return rv;
+}
+
 // バージョンを表示
 void
 MainApp::ShowVersion() const
@@ -909,10 +985,7 @@ MainApp::ParseLogopt()
 	for (const auto& item : items) {
 		if (item == "help") {
 			std::vector<std::string> list = GetLogNames();
-			// less したいだろうから stderr ではなく stdout に出力する
-			for (const auto& name : list) {
-				printf(" %s\n", name.c_str());
-			}
+			ShowHelpList(stdout, list);
 			return false;
 		}
 	}
@@ -927,6 +1000,65 @@ MainApp::ParseLogopt()
 	return true;
 }
 
+// list を一覧表示をする。-Lhelp, -Mhelp 用。
+/*static*/ void
+MainApp::ShowHelpList(FILE *fp, const std::vector<std::string>& list)
+{
+	int width = 0;
+
+	// 端末なら桁数を取得。
+	int fd = fileno(fp);
+	if (isatty(fd)) {
+		struct winsize ws;
+		if (ioctl(fd, TIOCGWINSZ, &ws) == 0) {
+			width = ws.ws_col;
+		}
+	}
+
+	if (width == 0) {
+		// パイプかリダイレクトなので垂れ流す。
+		for (const auto& name : list) {
+			fprintf(fp, " %s\n", name.c_str());
+		}
+	} else {
+		// 桁数が取得できたので ls(1) みたいに表示する。
+
+		uint maxlen = 0;
+		for (const auto& name : list) {
+			maxlen = std::max(maxlen, (uint)name.size());
+		}
+		// 余白分。
+		maxlen += 2;
+
+		const int LeftPadding = 1;
+		int ncol = (width - LeftPadding) / maxlen;
+		int nrow = (list.size() + ncol - 1) / ncol;
+		for (int row = 0; row < nrow; row++) {
+			fprintf(fp, " ");
+			for (int col = 0; col < ncol; col++) {
+				int idx = col * nrow + row;
+				if (idx < list.size()) {
+					fprintf(fp, "%-*s", maxlen, list[idx].c_str());
+				}
+			}
+			fprintf(fp, "\n");
+		}
+	}
+}
+
+// ログレベル指定文字列を処理する。早期処理用。
+// この上の ParseLogopt() と概ね同じだが、"help" を含めて知らないものは
+// スルーし、エラーが起きてもエラーメッセージも出力しない。
+void
+MainApp::ParseLogoptEarly()
+{
+	std::vector<std::string> items;
+	items = string_split(logopt.c_str(), ',');
+
+	std::string errmsg;
+	SetLogopt(items, &errmsg);
+}
+
 // ログレベルを設定する。
 // ログレベル指定文字列を 1つずつに分解したリスト items を処理する。
 // "help" があるケースはここに来るまでに処理してあるので、ここには来ない。
