@@ -66,9 +66,6 @@ class Monitor;
 using MonitorCallback_t = void (Object::*)(Monitor *, TextScreen&);
 #define ToMonitorCallback(f) static_cast<MonitorCallback_t>(f)
 
-// モニタ更新を呼び出すマクロ
-#define MONITOR_UPDATE(m, scr) ((((m)->obj)->*((m)->func))((m), (scr)))
-
 // モニタ
 class Monitor
 {
@@ -99,13 +96,18 @@ class Monitor
 	// このモニターの ID を表示用文字列にして返す。
 	const char *GetIdText() const { return GetIdText(id); }
 
+	// モニタを更新する。
+	void Update(TextScreen& screen) {
+		(obj->*(func))(this, screen);
+	}
+
 	Object *obj {};				// オブジェクト
 
 	MonitorCallback_t func {};	// コールバック関数
 
  private:
 	// モニター識別子
-	uint id;
+	uint id {};
 
 	// モニターサイズ
 	nnSize size {};
@@ -168,8 +170,8 @@ class MonitorManager
 		return info[id].aliases;
 	}
 
-	// id リストから一覧表示用の文字列を生成して返す
-	static std::string MakeListString(std::vector<uint> list);
+	// id リストから一覧表示用の文字列リストを生成して返す
+	std::vector<std::string> MakeListString(std::vector<uint> list) const;
 
 	// 以降の追加を禁止する (プログラムミスを避けるため)
 	void Fix();
