@@ -391,9 +391,9 @@ m68030TC::MakeMask()
 	//         +--------+--------+--------+--------+
 	// lmask  = 00000000 11111111 11100000 00000000
 	// pgmask = 00000000 00000000 00011111 11111111
-	lmask = (1 << (tia + tib + tic + tid)) - 1;
+	lmask = (1U << (tia + tib + tic + tid)) - 1;
 	lmask <<= ps;
-	pgmask = (1 << ps) - 1;
+	pgmask = (1U << ps) - 1;
 
 	// アドレスを (IS,) TIA 〜 TID に分解。
 	//
@@ -410,7 +410,7 @@ m68030TC::MakeMask()
 	for (int i = TID; i >= TIA; i--) {
 		if (tix[i] > 0) {
 			shift[i] = sh;
-			mask[i] = (1 << tix[i]) - 1;
+			mask[i] = (1U << tix[i]) - 1;
 			sh += tix[i];
 		}
 	}
@@ -653,7 +653,7 @@ m68030ATCTable::MakeHash(const m68030ATCLine *a)
 	if (__predict_true(ps4k == 0)) {
 		hash[addr4k] = idx;
 	} else if (ps4k > 0) {
-		for (int i = 0; i < (1 << ps4k); i++) {
+		for (int i = 0; i < (1U << ps4k); i++) {
 			hash[addr4k + i] = idx;
 		}
 	} else {
@@ -901,7 +901,7 @@ m68030MMU::search(int level, busaddr laddr)
 		 case DT_VALID4:	// 有効4バイト
 		 case DT_VALID8:	// 有効8バイト
 			m_lastsize = m_descsize;
-			m_descsize = 1 << dt;
+			m_descsize = 1U << dt;
 			break;
 		}
 	}
@@ -950,7 +950,7 @@ m68030MMU::search(int level, busaddr laddr)
 		 case DT_VALID4:	// 有効4バイト
 		 case DT_VALID8:	// 有効8バイト
 			m_lastsize = m_descsize;
-			m_descsize = 1 << dt;
+			m_descsize = 1U << dt;
 
 			if (__predict_false(x == TID || cpu->mmu_tc.tix[x + 1] == 0)) {
 				// 間接
