@@ -7,6 +7,7 @@
 #include "mpu680x0.h"
 #include "bitops.h"
 #include "debugger.h"
+#include "event.h"
 #include "interrupt.h"
 #include "mainbus.h"
 #include "scheduler.h"
@@ -20,7 +21,7 @@
 // 1命令実行する。
 // 割り込みチェックなどを省いたショート版。
 void
-MPU680x0Device::ExecShort(Event& ev)
+MPU680x0Device::ExecShort(Event *ev)
 {
 	uint64 cycle_start = used_cycle;
 
@@ -70,7 +71,7 @@ MPU680x0Device::ExecShort(Event& ev)
 	// 外部割り込みの起動は VM 側で処理している。
 
 	int cycle = used_cycle - cycle_start;
-	ev.time = cycle * clock_nsec + buswait;
+	ev->time = cycle * clock_nsec + buswait;
 	scheduler->StartEvent(ev);
 }
 
