@@ -47,7 +47,10 @@ do {	\
 	if (t == 0) {	\
 		v = u2f(reg.r[n]);	\
 	} else if (t == 1) {	\
-		v = u2d(((uint64)reg.r[n] << 32) | reg.r[(n + 1) & 31]);	\
+		uint64 tmp = (uint64)reg.r[n] << 32;	\
+		if (__predict_true(n != 31))	\
+			tmp |= reg.r[n + 1];	\
+		v = u2d(tmp);	\
 	} else {	\
 		FPPreciseException(FPECR_FROP);	\
 		return;	\
@@ -70,6 +73,13 @@ do {	\
 	}	\
 } while (0)
 
+#define CHECK_FPU	do {	\
+	if (IsFPUEnable() == false) {	\
+		FPPreciseException(FPECR_FUNIMP);	\
+		return;	\
+	}	\
+} while (0)
+
 // ブランチ命令
 void
 MPU88xx0Device::DoBranch(uint32 toaddr, bool next_exec)
@@ -299,7 +309,7 @@ static int rm_to_round[4] = {
 OP_DEF(xmem_bu_imm)
 {
 	uint32 addr;
-	uint64 tmp;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(1);
@@ -307,21 +317,21 @@ OP_DEF(xmem_bu_imm)
 	AddCycle(4);	// Table.7-3
 
 	lastaddr = addr;
-	tmp = cmmu[1]->xmem_1(addr, rD & 0xff);
-	if ((int64)tmp < 0) {
+	data = cmmu[1]->xmem_1(addr, rD & 0xff);
+	if (__predict_false(data.IsBusErr())) {
 		XmemDataException(addr, DM_BU);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = tmp;
+	rD = data.Data();
 }
 
 // 000001_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(xmem_w_imm)
 {
 	uint32 addr;
-	uint64 tmp;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(4);
@@ -329,21 +339,21 @@ OP_DEF(xmem_w_imm)
 	AddCycle(4);	// Table.7-3
 
 	lastaddr = addr;
-	tmp = cmmu[1]->xmem_4(addr, rD);
-	if ((int64)tmp < 0) {
+	data = cmmu[1]->xmem_4(addr, rD);
+	if (__predict_false(data.IsBusErr())) {
 		XmemDataException(addr, DM_W);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = tmp;
+	rD = data.Data();
 }
 
 // 000010_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(ld_hu_imm)
 {
 	uint32 addr;
-	uint64 data;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(2);
@@ -352,20 +362,20 @@ OP_DEF(ld_hu_imm)
 
 	lastaddr = addr;
 	data = cmmu[1]->load_2(addr);
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_HU);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = data;
+	rD = data.Data();
 }
 
 // 000011_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(ld_bu_imm)
 {
 	uint32 addr;
-	uint64 data;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(1);
@@ -374,21 +384,20 @@ OP_DEF(ld_bu_imm)
 
 	lastaddr = addr;
 	data = cmmu[1]->load_1(addr);
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_BU);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = data;
+	rD = data.Data();
 }
 
 // 000100_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(ld_d_imm)
 {
-	uint32 addr;
-	uint32 dae_addr;	// ReadDataException64() に渡すのは常に先頭アドレス。
-	uint64 data;
+	uint32 addr;	// ReadDataException64() に渡すのは常に先頭アドレス。
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(8);
@@ -396,26 +405,24 @@ OP_DEF(ld_d_imm)
 	AddCycle(4);	// Table.7-3
 
 	lastaddr = addr;
-	dae_addr = addr;
 
 	data = cmmu[1]->load_4(addr);
-	if ((int64)data < 0) {
-		ReadDataException64(dae_addr, DM_D1);
+	if (__predict_false(data.IsBusErr())) {
+		ReadDataException64(addr, DM_D1);
 		return;
 	}
 	if (__predict_true(FLD_D != 0)) {
-		rD = data;
+		rD = data.Data();
 	}
 
-	addr += 4;
-	data = cmmu[1]->load_4(addr);
-	if ((int64)data < 0) {
-		ReadDataException64(dae_addr, DM_D2);
+	data = cmmu[1]->load_4(addr + 4);
+	if (__predict_false(data.IsBusErr())) {
+		ReadDataException64(addr, DM_D2);
 		return;
 	}
 
 	if (__predict_true(FLD_D2 != 0)) {
-		rD2 = data;
+		rD2 = data.Data();
 	}
 }
 
@@ -423,7 +430,7 @@ OP_DEF(ld_d_imm)
 OP_DEF(ld_w_imm)
 {
 	uint32 addr;
-	uint64 data;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(4);
@@ -432,20 +439,20 @@ OP_DEF(ld_w_imm)
 
 	lastaddr = addr;
 	data = cmmu[1]->load_4(addr);
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_W);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = data;
+	rD = data.Data();
 }
 
 // 000110_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(ld_h_imm)
 {
 	uint32 addr;
-	uint64 data;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(2);
@@ -454,20 +461,20 @@ OP_DEF(ld_h_imm)
 
 	lastaddr = addr;
 	data = cmmu[1]->load_2(addr);
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_H);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = (uint32)(int32)(int16)data;
+	rD = (uint32)(int32)(int16)data.Data();
 }
 
 // 000111_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(ld_b_imm)
 {
 	uint32 addr;
-	uint64 data;
+	busdata data;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(1);
@@ -476,21 +483,20 @@ OP_DEF(ld_b_imm)
 
 	lastaddr = addr;
 	data = cmmu[1]->load_1(addr);
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_B);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = (uint32)(int32)(int8)data;
+	rD = (uint32)(int32)(int8)data.Data();
 }
 
 // 001000_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(st_d_imm)
 {
-	uint32 addr;
-	uint32 dae_addr;	// WriteDataException64() に渡すのは常に先頭アドレス。
-	uint64 rv;
+	uint32 addr;	// WriteDataException64() に渡すのは常に先頭アドレス。
+	busdata r;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(8);
@@ -498,18 +504,16 @@ OP_DEF(st_d_imm)
 	AddCycle(1 + 4);	// Table.7-3
 
 	lastaddr = addr;
-	dae_addr = addr;
 
-	rv = cmmu[1]->store_4(addr, rD);
-	if ((int64)rv < 0) {
-		WriteDataException64(dae_addr, DM_D1);
+	r = cmmu[1]->store_4(addr, rD);
+	if (__predict_false(r.IsBusErr())) {
+		WriteDataException64(addr, DM_D1);
 		return;
 	}
 
-	addr += 4;
-	rv = cmmu[1]->store_4(addr, rD2);
-	if ((int64)rv < 0) {
-		WriteDataException64(dae_addr, DM_D2);
+	r = cmmu[1]->store_4(addr + 4, rD2);
+	if (__predict_false(r.IsBusErr())) {
+		WriteDataException64(addr, DM_D2);
 		return;
 	}
 }
@@ -518,7 +522,7 @@ OP_DEF(st_d_imm)
 OP_DEF(st_w_imm)
 {
 	uint32 addr;
-	uint64 rv;
+	busdata r;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(4);
@@ -526,8 +530,8 @@ OP_DEF(st_w_imm)
 	AddCycle(3);	// Table.7-3
 
 	lastaddr = addr;
-	rv = cmmu[1]->store_4(addr, rD);
-	if ((int64)rv < 0) {
+	r = cmmu[1]->store_4(addr, rD);
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_W);
 		return;
 	}
@@ -537,7 +541,7 @@ OP_DEF(st_w_imm)
 OP_DEF(st_h_imm)
 {
 	uint32 addr;
-	uint64 rv;
+	busdata r;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(2);
@@ -545,8 +549,8 @@ OP_DEF(st_h_imm)
 	AddCycle(3);	// Table.7-3
 
 	lastaddr = addr;
-	rv = cmmu[1]->store_2(addr, rD & 0xffff);
-	if ((int64)rv < 0) {
+	r = cmmu[1]->store_2(addr, rD & 0xffff);
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_H);
 		return;
 	}
@@ -556,7 +560,7 @@ OP_DEF(st_h_imm)
 OP_DEF(st_b_imm)
 {
 	uint32 addr;
-	uint64 rv;
+	busdata r;
 
 	addr = rS1 + IMM16;
 	LDST_ALIGN(1);
@@ -564,8 +568,8 @@ OP_DEF(st_b_imm)
 	AddCycle(3);	// Table.7-3
 
 	lastaddr = addr;
-	rv = cmmu[1]->store_1(addr, rD & 0xff);
-	if ((int64)rv < 0) {
+	r = cmmu[1]->store_1(addr, rD & 0xff);
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_B);
 		return;
 	}
@@ -686,10 +690,7 @@ OP_DEF(subu_imm)
 // 011010_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(divu_imm)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(38);	// Table.7-6 (ただしざっくり)
 
@@ -705,10 +706,7 @@ OP_DEF(divu_imm)
 // 011011_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(mul_imm)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(4);	// Table.7-6 (ただしざっくり)
 
@@ -748,10 +746,7 @@ OP_DEF(sub_imm)
 // 011110_DDDDDSSSSS_nnnnnn_nnnnnnnnnn
 OP_DEF(div_imm)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(38);	// Table.7-6 (ただしざっくり)
 
@@ -775,7 +770,7 @@ OP_DEF(cmp_imm)
 // 100000_DDDDDzzzzz_01000n_nnnnnzzzzz
 OP_DEF(ldcr)
 {
-	if (IsUser()) {
+	if (__predict_false(IsUser())) {
 		Exception(EXCPRI_PRIV);
 		return;
 	}
@@ -807,7 +802,7 @@ OP_DEF(fldcr)
 	if (n >= 62) {
 		n = n - 62 + 9;
 	} else {
-		if (IsUser()) {
+		if (__predict_false(IsUser())) {
 			FPPreciseException(FPECR_FPRV);
 			return;
 		}
@@ -826,7 +821,7 @@ OP_DEF(fldcr)
 // 100000_zzzzzSSSSS_10000n_nnnnnsssss
 OP_DEF(stcr)
 {
-	if (IsUser()) {
+	if (__predict_false(IsUser())) {
 		Exception(EXCPRI_PRIV);
 		return;
 	}
@@ -864,7 +859,7 @@ OP_DEF(fstcr)
 	if (n >= 62) {
 		n = n - 62 + 9;
 	} else {
-		if (IsUser()) {
+		if (__predict_false(IsUser())) {
 			FPPreciseException(FPECR_FPRV);
 			return;
 		}
@@ -888,7 +883,7 @@ OP_DEF(xcr)
 {
 	uint32 tmp;
 
-	if (IsUser()) {
+	if (__predict_false(IsUser())) {
 		Exception(EXCPRI_PRIV);
 		return;
 	}
@@ -926,7 +921,7 @@ OP_DEF(fxcr)
 	// FCR9..61 read0	FPRV	FUNIMP	FPRV
 	// FCR62,63 xchg	xchg	xchg	xchg
 
-	if (IsUser() && n < 62) {
+	if (__predict_false(IsUser()) && n < 62) {
 		FPPreciseException(FPECR_FPRV);
 		return;
 	}
@@ -957,10 +952,10 @@ OP_DEF(fxcr)
 // 100001_DDDDDSSSSS_00000n_nnnnnsssss
 OP_DEF(fmul)
 {
-	// 暫定
 	double s1;
 	double s2;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -974,7 +969,7 @@ OP_DEF(fmul)
 // 100001_DDDDD00000_001000_000nnsssss
 OP_DEF(flt)
 {
-	// 暫定
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -987,10 +982,10 @@ OP_DEF(flt)
 // 100001_DDDDDSSSSS_00101n_nnnnnsssss
 OP_DEF(fadd)
 {
-	// 暫定
 	double s1;
 	double s2;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -1004,10 +999,10 @@ OP_DEF(fadd)
 // 100001_DDDDDSSSSS_00110n_nnnnnsssss
 OP_DEF(fsub)
 {
-	// 暫定
 	double s1;
 	double s2;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -1024,6 +1019,7 @@ OP_DEF(fcmp)
 	double s1;
 	double s2;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -1080,6 +1076,7 @@ MPU88xx0Device::ops_int(int rndmode)
 	double res;
 	int exponent;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -1131,10 +1128,10 @@ OP_DEF(trnc)
 // 100001_DDDDDSSSSS_01110n_nnnnnsssss
 OP_DEF(fdiv)
 {
-	// 暫定
 	double s1;
 	double s2;
 
+	CHECK_FPU;
 	if (FLD_D == 0) {
 		FPPreciseException(FPECR_FUNIMP);
 		return;
@@ -1246,7 +1243,7 @@ OP_DEF(set_1)
 OP_DEF(ext_1)
 {
 	int w, o, left;
-	uint32 tmp;
+	uint32 res;
 
 	if (FLD_D == 0)
 		return;
@@ -1255,16 +1252,16 @@ OP_DEF(ext_1)
 		w = 32;
 	o = O5;
 	left = 32 - w - o;
-	tmp = ASL(rS1, left);
-	tmp = ASR(tmp, left);
-	rD = ASR(tmp, o);
+	res = ASL(rS1, left);
+	res = ASR(res, left);
+	rD = ASR(res, o);
 }
 
 // 111100_DDDDDSSSSS_100110_wwwwwooooo
 OP_DEF(extu_1)
 {
 	int w, o, left;
-	uint32 tmp;
+	uint32 res;
 
 	if (FLD_D == 0)
 		return;
@@ -1273,9 +1270,9 @@ OP_DEF(extu_1)
 		w = 32;
 	o = O5;
 	left = 32 - w - o;
-	tmp = ASL(rS1, left);
-	tmp = LSR(tmp, left);
-	rD = tmp >> o;
+	res = ASL(rS1, left);
+	res = LSR(res, left);
+	rD = res >> o;
 }
 
 // 111100_DDDDDSSSSS_101000_wwwwwooooo
@@ -1358,7 +1355,7 @@ OP_DEF(tcnd)
 // 111101_DDDDDSSSSS_000000_xU000sssss
 OP_DEF(xmem_bu)
 {
-	uint64 tmp;
+	busdata data;
 	uint32 addr;
 	uint32 usr;
 
@@ -1370,22 +1367,22 @@ OP_DEF(xmem_bu)
 
 	// 例外安全のために都度 S/U ビットを制御
 	ENTER_USR();
-	tmp = cmmu[1]->xmem_1(addr, rD & 0xff);
+	data = cmmu[1]->xmem_1(addr, rD & 0xff);
 	LEAVE_USR();
 
-	if ((int64)tmp < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		XmemDataException(addr, DM_BU | usr);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = tmp;
+	rD = data.Data();
 }
 
 // 111101_DDDDDSSSSS_000001_xU000sssss
 OP_DEF(xmem_w)
 {
-	uint64 tmp;
+	busdata data;
 	uint32 addr;
 	uint32 usr;
 
@@ -1397,23 +1394,23 @@ OP_DEF(xmem_w)
 
 	// 例外安全のために都度 S/U ビットを制御
 	ENTER_USR();
-	tmp = cmmu[1]->xmem_4(addr, rD);
+	data = cmmu[1]->xmem_4(addr, rD);
 	LEAVE_USR();
 
-	if ((int64)tmp < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		XmemDataException(addr, DM_W | usr);
 		return;
 	}
 
 	if (FLD_D == 0)
 		return;
-	rD = tmp;
+	rD = data.Data();
 }
 
 // 111101_DDDDDSSSSS_000010_xU000sssss
 OP_DEF(ld_hu)
 {
-	uint64 data;
+	busdata data;
 	uint32 addr;
 	uint32 usr;
 
@@ -1427,20 +1424,20 @@ OP_DEF(ld_hu)
 	data = cmmu[1]->load_2(addr);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_HU | usr);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = data;
+	rD = data.Data();
 }
 
 // 111101_DDDDDSSSSS_000011_xU000sssss
 OP_DEF(ld_bu)
 {
-	uint64 data;
 	uint32 addr;
+	busdata data;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(1);
@@ -1453,21 +1450,20 @@ OP_DEF(ld_bu)
 	data = cmmu[1]->load_1(addr);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_BU | usr);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = data;
+	rD = data.Data();
 }
 
 // 111101_DDDDDSSSSS_000100_xU000sssss
 OP_DEF(ld_d)
 {
-	uint32 addr;
-	uint32 dae_addr;	// ReadDataException64() に渡すのは常に先頭アドレス。
-	uint64 data;
+	uint32 addr;	// ReadDataException64() に渡すのは常に先頭アドレス。
+	busdata data;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(8);
@@ -1475,41 +1471,38 @@ OP_DEF(ld_d)
 	AddCycle(4);	// Table.7-3
 
 	lastaddr = addr;
-	dae_addr = addr;
 
 	// 例外安全のために都度 S/U ビットを制御
 	ENTER_USR();
 	data = cmmu[1]->load_4(addr);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
-		ReadDataException64(dae_addr, DM_D1 | usr);
+	if (__predict_false(data.IsBusErr())) {
+		ReadDataException64(addr, DM_D1 | usr);
 		return;
 	}
 	if (__predict_true(FLD_D != 0)) {
-		rD = data;
+		rD = data.Data();
 	}
 
-	addr += 4;
-
 	ENTER_USR();
-	data = cmmu[1]->load_4(addr);
+	data = cmmu[1]->load_4(addr + 4);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
-		ReadDataException64(dae_addr, DM_D2 | usr);
+	if (__predict_false(data.IsBusErr())) {
+		ReadDataException64(addr, DM_D2 | usr);
 		return;
 	}
 	if (__predict_true(FLD_D2 != 0)) {
-		rD2 = data;
+		rD2 = data.Data();
 	}
 }
 
 // 111101_DDDDDSSSSS_000101_xU000sssss
 OP_DEF(ld_w)
 {
-	uint64 data;
 	uint32 addr;
+	busdata data;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(4);
@@ -1534,8 +1527,8 @@ OP_DEF(ld_w)
 // 111101_DDDDDSSSSS_000110_xU000sssss
 OP_DEF(ld_h)
 {
-	uint64 data;
 	uint32 addr;
+	busdata data;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(2);
@@ -1548,20 +1541,20 @@ OP_DEF(ld_h)
 	data = cmmu[1]->load_2(addr);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_H | usr);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = (uint32)(int32)(int16)data;
+	rD = (uint32)(int32)(int16)data.Data();
 }
 
 // 111101_DDDDDSSSSS_000111_xU000sssss
 OP_DEF(ld_b)
 {
-	uint64 data;
 	uint32 addr;
+	busdata data;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(1);
@@ -1574,21 +1567,20 @@ OP_DEF(ld_b)
 	data = cmmu[1]->load_1(addr);
 	LEAVE_USR();
 
-	if ((int64)data < 0) {
+	if (__predict_false(data.IsBusErr())) {
 		ReadDataException32(addr, DM_B | usr);
 		return;
 	}
 	if (FLD_D == 0)
 		return;
-	rD = (uint32)(int32)(int8)data;
+	rD = (uint32)(int32)(int8)data.Data();
 }
 
 // 111101_DDDDDSSSSS_001000_xU000sssss
 OP_DEF(st_d)
 {
-	uint64 rv;
-	uint32 addr;
-	uint32 dae_addr;	// WriteDataException64() に渡すのは常に先頭アドレス。
+	uint32 addr;	// WriteDataException64() に渡すのは常に先頭アドレス。
+	busdata r;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(8);
@@ -1596,25 +1588,22 @@ OP_DEF(st_d)
 	AddCycle(1 + 4);	// Table.7-3
 
 	lastaddr = addr;
-	dae_addr = addr;
 
 	ENTER_USR();
-	rv = cmmu[1]->store_4(addr, rD);
+	r = cmmu[1]->store_4(addr, rD);
 	LEAVE_USR();
 
-	if ((int64)rv < 0) {
-		WriteDataException64(dae_addr, DM_D1 | usr);
+	if (__predict_false(r.IsBusErr())) {
+		WriteDataException64(addr, DM_D1 | usr);
 		return;
 	}
 
-	addr += 4;
-
 	ENTER_USR();
-	rv = cmmu[1]->store_4(addr, rD2);
+	r = cmmu[1]->store_4(addr + 4, rD2);
 	LEAVE_USR();
 
-	if ((int64)rv < 0) {
-		WriteDataException64(dae_addr, DM_D2 | usr);
+	if (__predict_false(r.IsBusErr())) {
+		WriteDataException64(addr, DM_D2 | usr);
 		return;
 	}
 }
@@ -1622,8 +1611,8 @@ OP_DEF(st_d)
 // 111101_DDDDDSSSSS_001001_xU000sssss
 OP_DEF(st_w)
 {
-	uint64 rv;
 	uint32 addr;
+	busdata r;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(4);
@@ -1633,10 +1622,10 @@ OP_DEF(st_w)
 	lastaddr = addr;
 
 	ENTER_USR();
-	rv = cmmu[1]->store_4(addr, rD);
+	r = cmmu[1]->store_4(addr, rD);
 	LEAVE_USR();
 
-	if ((int64)rv < 0) {
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_W | usr);
 		return;
 	}
@@ -1645,8 +1634,8 @@ OP_DEF(st_w)
 // 111101_DDDDDSSSSS_001010_xU000sssss
 OP_DEF(st_h)
 {
-	uint64 rv;
 	uint32 addr;
+	busdata r;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(2);
@@ -1656,10 +1645,10 @@ OP_DEF(st_h)
 	lastaddr = addr;
 
 	ENTER_USR();
-	rv = cmmu[1]->store_2(addr, rD & 0xffff);
+	r = cmmu[1]->store_2(addr, rD & 0xffff);
 	LEAVE_USR();
 
-	if ((int64)rv < 0) {
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_H | usr);
 		return;
 	}
@@ -1668,8 +1657,8 @@ OP_DEF(st_h)
 // 111101_DDDDDSSSSS_001011_xU000sssss
 OP_DEF(st_b)
 {
-	uint64 rv;
 	uint32 addr;
+	busdata r;
 	uint32 usr;
 
 	LDST_USR_SCALE_ALIGN(1);
@@ -1679,10 +1668,10 @@ OP_DEF(st_b)
 	lastaddr = addr;
 
 	ENTER_USR();
-	rv = cmmu[1]->store_1(addr, rD & 0xff);
+	r = cmmu[1]->store_1(addr, rD & 0xff);
 	LEAVE_USR();
 
-	if ((int64)rv < 0) {
+	if (__predict_false(r.IsBusErr())) {
 		WriteDataException32(addr, DM_B | usr);
 		return;
 	}
@@ -1828,10 +1817,7 @@ OP_DEF(subu)
 // 111101_DDDDDSSSSS_011010_zz000sssss
 OP_DEF(divu)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(38);	// Table.7-6 (ただしざっくり)
 
@@ -1847,10 +1833,7 @@ OP_DEF(divu)
 // 111101_DDDDDSSSSS_011011_zz000sssss
 OP_DEF(mul)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(4);	// Table.7-6 (ただしざっくり)
 
@@ -1909,10 +1892,7 @@ OP_DEF(sub)
 // 111101_DDDDDSSSSS_011110_zz000sssss
 OP_DEF(div)
 {
-	if (!IsFPUEnable()) {
-		fpu_unimpl();
-		return;
-	}
+	CHECK_FPU;
 
 	AddCycle(38);	// Table.7-6 (ただしざっくり)
 
@@ -1953,7 +1933,7 @@ OP_DEF(set_2)
 OP_DEF(ext_2)
 {
 	int w, o, left;
-	uint32 tmp;
+	uint32 res;
 
 	if (FLD_D == 0)
 		return;
@@ -1962,16 +1942,16 @@ OP_DEF(ext_2)
 		w = 32;
 	o = (rS2     ) & 0x1f;
 	left = 32 - w - o;
-	tmp = ASL(rS1, left);
-	tmp = ASR(tmp, left);
-	rD = ASR(tmp, o);
+	res = ASL(rS1, left);
+	res = ASR(res, left);
+	rD = ASR(res, o);
 }
 
 // 111101_DDDDDSSSSS_100110_00000sssss
 OP_DEF(extu_2)
 {
 	int w, o, left;
-	uint32 tmp;
+	uint32 res;
 
 	if (FLD_D == 0)
 		return;
@@ -1980,9 +1960,9 @@ OP_DEF(extu_2)
 		w = 32;
 	o = (rS2     ) & 0x1f;
 	left = 32 - w - o;
-	tmp = ASL(rS1, left);
-	tmp = LSR(tmp, left);
-	rD = tmp >> o;
+	res = ASL(rS1, left);
+	res = LSR(res, left);
+	rD = res >> o;
 }
 
 // 111101_DDDDDSSSSS_101000_00000sssss
@@ -2081,6 +2061,11 @@ OP_DEF(ff0)
 // 111101_zzzzzzzzzz_111111_0000000000
 OP_DEF(rte)
 {
+	if (__predict_false(IsUser())) {
+		Exception(EXCPRI_PRIV);
+		return;
+	}
+
 	AddCycle(2);	// Table.7-5
 
 	SetPSR(reg.epsr);
