@@ -400,18 +400,18 @@ class m88200 : public Device
 	// アクセス関数
 	//
  private:
-	template <uint size> uint64 load(uint32 addr);
-	template <uint size> uint64 store(uint32 addr, uint32 data);
-	template <uint size> uint64 xmem(uint32 addr, uint32 data);
+	template <uint size> busdata load(uint32 addr);
+	template <uint size> busdata store(uint32 addr, uint32 data);
+	template <uint size> busdata xmem(uint32 addr, uint32 data);
  public:
-	uint64 load_1(uint32 addr);
-	uint64 load_2(uint32 addr);
-	uint64 load_4(uint32 addr);
-	uint64 store_1(uint32 addr, uint32 data);
-	uint64 store_2(uint32 addr, uint32 data);
-	uint64 store_4(uint32 addr, uint32 data);
-	uint64 xmem_1(uint32 addr, uint32 data);
-	uint64 xmem_4(uint32 addr, uint32 data);
+	busdata load_1(uint32 addr);
+	busdata load_2(uint32 addr);
+	busdata load_4(uint32 addr);
+	busdata store_1(uint32 addr, uint32 data);
+	busdata store_2(uint32 addr, uint32 data);
+	busdata store_4(uint32 addr, uint32 data);
+	busdata xmem_1(uint32 addr, uint32 data);
+	busdata xmem_4(uint32 addr, uint32 data);
 
 	//
 	// 現在のアクセス中の状態。
@@ -537,6 +537,8 @@ class m88200 : public Device
 	static int patc_hash_func(uint32 a) {
 		return (a >> 12) & 0xff;
 	}
+	// 空きエントリ。patc[N] が空いていればビット N を立てる。
+	uint64 patc_free {};
 	// 次回追加する位置。
 	int patc_next {};
 
