@@ -51,6 +51,9 @@ class BankRAMDevice : public IODevice
 	// ページ番号をリニアアドレスにした状態で保持。
 	uint32 pageaddr {};
 
+	// ウェイト [nsec]
+	busdata wait {};
+
 	// アクセス状況
 	alignas(8) uint8 accstat_read[AccStat::BANKLEN] {};
 	alignas(8) uint8 accstat_write[AccStat::BANKLEN] {};
