@@ -50,7 +50,7 @@ ConsoleDevice::~ConsoleDevice()
 bool
 ConsoleDevice::Init()
 {
-	renderer = GetRenderer();
+	renderer = GetVideoRenderer();
 
 	// ログファイル。
 	if (gMainApp.console_logfile) {
