@@ -30,7 +30,7 @@ bool
 CRTC2Device::Init()
 {
 	lunafb = GetLunafbDevice();
-	renderer = GetRenderer();
+	renderer = GetVideoRenderer();
 
 	auto evman = GetEventManager();
 	vdisp_event = evman->Regist(this,
