@@ -252,7 +252,7 @@ LunafbDevice::WriteReg(busaddr addr, uint32 data)
 		WriteRFCNT(data);
 	} else {
 		// BMSEL
-		bmsel = data & ((1 << nplane) - 1);
+		bmsel = data & ((1U << nplane) - 1);
 		putlog(1, "BMSEL <- $%08x", data);
 	}
 
@@ -310,7 +310,7 @@ LunafbDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	for (i = 0; i < nplane; i++) {
 		screen.Print(0, 3 + i, "Plane#%u %s %s $%08x",
 			i,
-			(bmsel & (1 << i)) ? "Sel" : "---",
+			(bmsel & (1U << i)) ? "Sel" : "---",
 			RopStr(fcset[i]), fcmask[i]);
 	}
 	for (; i < MAX_PLANES; i++) {
@@ -391,7 +391,7 @@ LunafbDevice::WriteCommonBitmap8(uint32 addr, uint32 data)
 	uint32 offset = addr - 0xb1080000;
 	putlog(2, "Common Plane $%08x <- $%02x", addr, data);
 	for (int i = 0; i < nplane; i++) {
-		if ((bmsel & (1 << i))) {
+		if ((bmsel & (1U << i))) {
 			WritePlane8(i, offset, data);
 		}
 	}
@@ -405,7 +405,7 @@ LunafbDevice::WriteCommonBitmap16(uint32 addr, uint32 data)
 	uint32 offset = addr - 0xb1080000;
 	putlog(2, "Common Plane $%08x <- $%04x", addr, data);
 	for (int i = 0; i < nplane; i++) {
-		if ((bmsel & (1 << i))) {
+		if ((bmsel & (1U << i))) {
 			WritePlane16(i, offset, data);
 		}
 	}
@@ -419,7 +419,7 @@ LunafbDevice::WriteCommonBitmap32(uint32 addr, uint32 data)
 	uint32 offset = addr - 0xb1080000;
 	putlog(2, "Common Plane $%08x <- $%08x", addr, data);
 	for (int i = 0; i < nplane; i++) {
-		if ((bmsel & (1 << i))) {
+		if ((bmsel & (1U << i))) {
 			WritePlane32(i, offset, data);
 		}
 	}
@@ -431,7 +431,7 @@ void
 LunafbDevice::WriteCommonFCSet(uint rop, uint32 data)
 {
 	for (int i = 0; i < nplane; i++) {
-		if ((bmsel & (1 << i))) {
+		if ((bmsel & (1U << i))) {
 			fcset[i] = rop;
 			fcmask[i] = data;
 		}
@@ -651,7 +651,7 @@ void
 LunafbDevice::EmuInitScreen()
 {
 	// 同時書き込み設定
-	bmsel = (1 << nplane) - 1;
+	bmsel = (1U << nplane) - 1;
 
 	// ROP を初期化
 	WriteCommonFCSet(ROP::THRU, 0xffffffff);
