@@ -16,6 +16,7 @@
 // 同様に高速走行を抑制したいため、キー扱いとしていることに留意。
 
 #include "lunakbd.h"
+#include "event.h"
 #include "monitor.h"
 #include "scheduler.h"
 #include "sio.h"
@@ -52,9 +53,10 @@ LunaKeyboard::Init()
 
 	sio = GetSIODevice();
 
-	event.func = ToEventCallback(&LunaKeyboard::Callback);
-	event.SetName("Keyboard/Mouse");
-	scheduler->RegistEvent(event);
+	auto evman = GetEventManager();
+	event = evman->Regist(this,
+		ToEventCallback(&LunaKeyboard::Callback),
+		"Keyboard/Mouse");
 
 	return true;
 }
@@ -212,7 +214,7 @@ LunaKeyboard::KeyInput(uint keystat)
 
 		// LED 状態が変更になったので全走査指示。
 		// KeyInputCommon() 内で一度ポストしてるので無駄気味だが仕方ない…
-		UIMessage::Post(UIMessage::KEYBOARD);
+		uimessage->Post(UIMessage::KEYBOARD);
 	}
 
 	// LUNA のキーボードはキーボード側でキーリピートしないので
@@ -276,8 +278,8 @@ LunaKeyboard::Start(uint64 period)
 	uint64 now = scheduler->GetVirtTime();
 	uint64 target = ((now / period) + 1) * period;
 	// XXX メンバの event.vtime 参照してるけどどうするかね
-	if (event.IsRunning() == false || target < event.vtime) {
-		event.time = target - now;
+	if (event->IsRunning() == false || target < event->vtime) {
+		event->time = target - now;
 		scheduler->RestartEvent(event);
 	}
 }
@@ -286,7 +288,7 @@ LunaKeyboard::Start(uint64 period)
 // キー入力、マウス入力、ブザー出力のいずれかが発生している間 2msec ごとに
 // 呼ばれる。
 void
-LunaKeyboard::Callback(Event& ev)
+LunaKeyboard::Callback(Event *ev)
 {
 	uint64 now = scheduler->GetVirtTime();
 	uint mdkey;
@@ -420,7 +422,7 @@ LunaKeyboard::Command(uint32 data)
 		uint code = data & 0x01;
 		uint on   = data & 0x10;
 		led[code] = (bool)on;
-		UIMessage::Post(UIMessage::KEYBOARD);
+		uimessage->Post(UIMessage::KEYBOARD);
 		if (loglevel >= 1) {
 			const auto name = GetKeyName(LED2Keycode(code));
 			putlogn("Command $%02x LED $%x(%s) %s",
