@@ -101,6 +101,7 @@
 // 使っていないので、Timer-B は実質何もしていない。
 
 #include "mfp.h"
+#include "event.h"
 #include "interrupt.h"
 #include "keyboard.h"
 #include "monitor.h"
@@ -143,19 +144,18 @@ MFPDevice::Init()
 		mfp.timer[ch].tdr = 256;
 	}
 
+	auto evman = GetEventManager();
 	for (int ch = 0; ch < event.size(); ch++) {
-		event[ch].dev = this;
-		event[ch].func = ToEventCallback(&MFPDevice::TimerCallback);
-		event[ch].code = ch;
-		event[ch].SetName(string_format("MFP Timer-%c", ch + 'A'));
-		scheduler->RegistEvent(event[ch]);
+		event[ch] = evman->Regist(this, ch,
+			ToEventCallback(&MFPDevice::TimerCallback),
+			string_format("MFP Timer-%c", ch + 'A'));
 	}
 
 	// キーボード周りは x68kkbd.cpp のコメント参照
-	key_event.func = ToEventCallback(&MFPDevice::KeyCallback);
-	key_event.time = 3750_usec;
-	key_event.SetName("MFP USART");
-	scheduler->RegistEvent(key_event);
+	key_event = evman->Regist(this,
+		ToEventCallback(&MFPDevice::KeyCallback),
+		"MFP USART");
+	key_event->time = 3750_usec;
 
 	return true;
 }
@@ -735,7 +735,7 @@ MFPDevice::SetIER(uint16 new_ier)
 	for (int ch = 0; ch < countof(mfp.timer); ch++) {
 		uint timer_mask = 1U << timer_vector[ch];
 		if ((raising & timer_mask) != 0 && mfp.timer[ch].IsDelay()) {
-			event[ch].SetName(string_format("MFP Timer-%c", ch + 'A'));
+			event[ch]->SetName(string_format("MFP Timer-%c", ch + 'A'));
 			RestartTimerEvent(ch);
 		}
 	}
@@ -802,13 +802,13 @@ MFPDevice::SetTCR(int ch, uint32 data)
 		uint64 now = scheduler->GetVirtTime();
 		timer.start = now;
 		if (IsTimerIntrEnable(ch)) {
-			event[ch].time = period * timer.tdr;
-			event[ch].SetName(string_format("MFP Timer-%c", ch + 'A'));
+			event[ch]->time = period * timer.tdr;
+			event[ch]->SetName(string_format("MFP Timer-%c", ch + 'A'));
 			if (sync_rt) {
 				// 自分の実時間軸の基準をここにする。
 				stime[ch] = syncer->GetRealTime();
 				// event.time はこの後変動するので、周期は別で覚えておく。
-				rt_period[ch] = event[ch].time;
+				rt_period[ch] = event[ch]->time;
 
 				scheduler->StartRealtimeEvent(event[ch],
 					stime[ch], rt_period[ch]);
@@ -816,7 +816,7 @@ MFPDevice::SetTCR(int ch, uint32 data)
 				scheduler->RestartEvent(event[ch]);
 			}
 		} else {
-			event[ch].SetName(string_format("MFP Timer-%c FreeRun", ch + 'A'));
+			event[ch]->SetName(string_format("MFP Timer-%c FreeRun", ch + 'A'));
 		}
 
 		putlog(1, "Timer-%c Start Delay mode(%u x %u.%uusec)",
@@ -904,9 +904,9 @@ MFPDevice::SetTDR(int ch, uint32 data)
 
 // イベントコールバック
 void
-MFPDevice::TimerCallback(Event& ev)
+MFPDevice::TimerCallback(Event *ev)
 {
-	int ch = ev.code;
+	int ch = ev->code;
 	MFP::Timer& timer = mfp.timer[ch];
 
 	// TDR がゼロになったところで呼ばれるので、TDR をリロードする
@@ -915,9 +915,9 @@ MFPDevice::TimerCallback(Event& ev)
 		timer.start = 0;
 		// TDR (のリロード値) が変わったのでタイマー周りも再設定。
 		uint64 period = prescale_ns[timer.tcr];
-		ev.time = period * timer.tdr;
+		ev->time = period * timer.tdr;
 		if (sync_rt) {
-			rt_period[ch] = ev.time;
+			rt_period[ch] = ev->time;
 		}
 	}
 
@@ -945,7 +945,7 @@ MFPDevice::TimerCallback(Event& ev)
 		}
 	} else {
 		// タイマー動作中に IER を下げた時にはここで次回以降のイベントを停止。
-		ev.SetName(string_format("MFP Timer-%c FreeRun", ch + 'A'));
+		ev->SetName(string_format("MFP Timer-%c FreeRun", ch + 'A'));
 	}
 }
 
@@ -960,7 +960,7 @@ MFPDevice::RestartTimerEvent(int ch)
 	uint64 now = scheduler->GetVirtTime();
 	uint64 period = prescale_ns[timer.tcr];
 	uint64 timeout = period * timer.tdr;
-	event[ch].time = timeout - ((now - timer.start) % timeout);
+	event[ch]->time = timeout - ((now - timer.start) % timeout);
 	scheduler->RestartEvent(event[ch]);
 }
 
@@ -969,7 +969,7 @@ void
 MFPDevice::StopTimerEvent(int ch)
 {
 	scheduler->StopEvent(event[ch]);
-	event[ch].SetName(string_format("MFP Timer-%c Stopped", ch + 'A'));
+	event[ch]->SetName(string_format("MFP Timer-%c Stopped", ch + 'A'));
 	mfp.timer[ch].start = 0;
 }
 
@@ -1169,7 +1169,7 @@ MFPDevice::RxIsReady() const
 	// だが、そもそもキーボードは送出作業中で、新たな送信はできないはずなので
 	// この場合、つまり key_event の動作中も false (送信不可) にする。
 
-	return !IsRR() && !key_event.IsRunning();
+	return !IsRR() && !key_event->IsRunning();
 }
 
 // キーボードからデータを受信
@@ -1179,16 +1179,16 @@ MFPDevice::Rx(uint32 data)
 	// ここは受信したビットをシフトレジスタへ入れ始めたところに相当する
 	// ので、まだ Buffer Full は立てない。
 
-	key_event.code = data;
+	key_event->code = data;
 	scheduler->RestartEvent(key_event);
 }
 
 // キーボードからのデータが受信し終わった頃に呼ばれるイベント。
 void
-MFPDevice::KeyCallback(Event& ev)
+MFPDevice::KeyCallback(Event *ev)
 {
 	// UDR にデータを置いて Buffer Full をセット
-	mfp.udr = ev.code;
+	mfp.udr = ev->code;
 	SetBF();
 
 	// Manual 7-5 7.2.1 Receiver Interrupt Channels より
