@@ -11,7 +11,6 @@
 #pragma once
 
 #include "device.h"
-#include "event.h"
 #include <array>
 
 class InterruptDevice;
@@ -279,8 +278,8 @@ class MFPDevice : public IODevice
 	bool IsRR() const;
 
 	// イベントコールバック
-	void TimerCallback(Event& ev);
-	void KeyCallback(Event& ev);
+	void TimerCallback(Event *);
+	void KeyCallback(Event *);
 
 	// 必要なら割り込みを上げる
 	void SetInterrupt(uint ch);
@@ -291,8 +290,8 @@ class MFPDevice : public IODevice
 	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
 
 	struct MFP mfp {};
-	std::array<Event, 4> event {};
-	Event key_event { this };
+	std::array<Event *, 4> event {};
+	Event *key_event {};
 
 	// 各タイマーが刻んでいる時刻 (時間軸)
 	std::array<uint64, 4> stime {};
