@@ -13,7 +13,6 @@
 #include "mpu.h"
 #include "branchhistory.h"
 #include "bus.h"
-#include "event.h"
 #include "m680x0.h"
 #include "m68030mmu.h"
 #include <array>
@@ -116,18 +115,18 @@ class MPU680x0Device : public MainMPUDevice
 
  protected:
 	// リセット例外コールバック
-	void ResetCallback(Event& ev);
+	void ResetCallback(Event *);
 
 	// 命令実行系コールバック
-	void ExecShort(Event& ev);
-	void ExecFull(Event& ev);
-	void ExecTrace(Event& ev);
+	void ExecShort(Event *);
+	void ExecFull(Event *);
+	void ExecTrace(Event *);
 
 	// トレース設定。デバッガから呼び出される。
 	void SetTrace(bool enable) override;
 
 	// 割り込みイベントコールバック
-	void InterruptCallback(Event& ev);
+	void InterruptCallback(Event *);
 
 	// 次の実行サイクルを Full にする。
 	void MakeNextFull();
@@ -440,7 +439,7 @@ class MPU680x0Device : public MainMPUDevice
 	BranchHistory_m680x0 exhist { OBJ_MPU_EXHIST };
 
 	// 割り込みイベント
-	Event intr_event { this };
+	Event *intr_event {};
 
 	// トレースでコールバックを差し替えることができるように
 	// イベントコールバックを変数に入れてある
