@@ -12,7 +12,6 @@
 
 #include "mpu.h"
 #include "branchhistory.h"
-#include "event.h"
 #include "m88100.h"
 #include "m88200.h"
 #include <array>
@@ -84,11 +83,11 @@ class MPU88xx0Device : public MainMPUDevice, private M88100
 
  private:
 	// リセット例外コールバック
-	void ResetCallback(Event& ev);
+	void ResetCallback(Event *);
 
 	// 命令実行系コールバック
-	void ExecNormal(Event& ev);
-	void ExecTrace(Event& ev);
+	void ExecNormal(Event *);
+	void ExecTrace(Event *);
 
 	// トレース設定。デバッガから呼び出される。
 	void SetTrace(bool enable) override;
@@ -168,8 +167,6 @@ class MPU88xx0Device : public MainMPUDevice, private M88100
 OP_PROTO(illegal);
 #undef OP_PROTO
 
-	void fpu_unimpl();
-
 	// float,double と整数値の相互変換
 	static float u2f(uint32 u) {
 		float v;
