@@ -12,7 +12,6 @@
 
 #include "device.h"
 #include "message.h"
-#include "event.h"
 
 class InterruptDevice;
 
@@ -36,11 +35,11 @@ class NMIDevice : public Device
 
  private:
 	void AssertMessage(MessageID, uint32);
-	void NegateCallback(Event& ev);
+	void NegateCallback(Event *);
 
 	InterruptDevice *interrupt {};
 
-	Event event { this };
+	Event *event {};
 };
 
 static inline NMIDevice *GetNMIDevice() {
