@@ -27,6 +27,7 @@
 //             +------------+
 
 #include "pio.h"
+#include "adpcm.h"
 #include "bitops.h"
 #include "dipsw.h"
 #include "event.h"
@@ -164,6 +165,15 @@ PPIDevice::~PPIDevice()
 {
 }
 
+// 初期化
+bool
+PPIDevice::Init()
+{
+	adpcm = GetADPCMDevice();
+
+	return true;
+}
+
 busdata
 PPIDevice::ReadPort(uint32 offset)
 {
@@ -175,8 +185,8 @@ PPIDevice::ReadPort(uint32 offset)
 		data = 0xff;
 		break;
 	 case 2:
-		putlog(0, "Read $e9a005 PortC (NOT IMPLEMENTED)");
-		data = 0xff;
+		data = GetPC();
+		putlog(1, "PortC -> $%02x", data.Data());
 		break;
 	 case 3:
 		putlog(0, "Read $e9a007 Ctrl (NOT IMPLEMENTED)");
@@ -222,22 +232,51 @@ PPIDevice::PeekPort(uint32 offset)
 	return 0xff;
 }
 
+// PortC 読み込み
+uint32
+PPIDevice::GetPC() const
+{
+	uint32 data = 0;
+
+	// パンの状態はこちらで持っていない。
+	if (adpcm->GetPanOutR() == false) {
+		data |= 0x01;
+	}
+	if (adpcm->GetPanOutL() == false) {
+		data |= 0x02;
+	}
+
+	// サンプリングレートは書き込み値をこちらでも持っている(ADPCMにもある)。
+	data |= adpcm_rate << 2;
+
+	// bit4: PC4 (通常 0)
+	// bit5: PC5 (通常 0)
+	// bit6: IOA5 (1=ジョイスティック#1のAが押された状態にする, 0=通常)
+	// bit6: IOA6 (1=ジョイスティック#1のBが押された状態にする, 0=通常)
+
+	return data;
+}
+
 // PortC 書き込み
 void
 PPIDevice::SetPC(uint pc, uint val)
 {
 	switch (pc) {
 	 case 0:	// ADPCM PAN Left Off
-		pan_left = !val;
+		adpcm->SetPanOutL(!val);
 		return;
 	 case 1:	// ADPCM PAN Right Off
-		pan_right = !val;
+		adpcm->SetPanOutR(!val);
 		return;
 	 case 2:	// ADPCM サンプリングレート
-		adpcm_rate = (adpcm_rate & 2) | val;
+		adpcm_rate &= ~1U;
+		adpcm_rate |= val ? 1U : 0;
+		adpcm->SetRate(adpcm_rate);
 		return;
 	 case 3:	// ADPCM サンプリングレート
-		adpcm_rate = (val << 1) | (adpcm_rate & 1);
+		adpcm_rate &= ~2U;
+		adpcm_rate |= val ? 2U : 0;
+		adpcm->SetRate(adpcm_rate);
 		return;
 
 	 case 4:	// ジョイスティック #1 コントロール
