@@ -5,7 +5,7 @@
 //
 
 //
-// レンダラ
+// ビデオレンダラ
 //
 
 #include "renderer.h"
@@ -34,23 +34,25 @@ static uint convert_count;
 static const Color ScreenOffColor(0x70, 0x70, 0x70);
 
 // コンストラクタ
-Renderer::Renderer()
-	: inherited(OBJ_RENDERER)
+VideoRenderer::VideoRenderer()
+	: inherited(OBJ_VIDEO_RENDERER)
 {
+	AddAlias("Renderer");
+
 	monitor = gMonitorManager->Regist(ID_MONITOR_RENDERER, this);
-	monitor->func = ToMonitorCallback(&Renderer::MonitorUpdate);
+	monitor->func = ToMonitorCallback(&VideoRenderer::MonitorUpdate);
 	monitor->SetSize(42, 10);
 }
 
 // デストラクタ
-Renderer::~Renderer()
+VideoRenderer::~VideoRenderer()
 {
 	TerminateThread();
 }
 
 // 初期化
 bool
-Renderer::Init()
+VideoRenderer::Init()
 {
 	syncer = GetSyncer();
 	uimessage = gMainApp.GetUIMessage();
@@ -68,7 +70,7 @@ Renderer::Init()
 
 // リセット
 void
-Renderer::ResetHard(bool poweron)
+VideoRenderer::ResetHard(bool poweron)
 {
 	next_refresh_rtime = syncer->GetRealTime();
 
@@ -90,7 +92,7 @@ Renderer::ResetHard(bool poweron)
 
 // 電源オフ
 void
-Renderer::PowerOff()
+VideoRenderer::PowerOff()
 {
 	if (enable) {
 #if defined(PERFREND)
@@ -106,7 +108,7 @@ Renderer::PowerOff()
 // 画面合成処理 (VM スレッドで呼ばれる)。
 // 今は一画面単位で合成を行なっている。ラスター云々は未対応。
 void
-Renderer::NotifyRender()
+VideoRenderer::NotifyRender()
 {
 	// CLI 版なら何もしない。
 	if (enable == false) {
@@ -133,7 +135,7 @@ Renderer::NotifyRender()
 
 // レンダリングスレッド
 void
-Renderer::ThreadRun()
+VideoRenderer::ThreadRun()
 {
 	if (enable) {
 		SetThreadAffinityHint(AffinityClass::Heavy);
@@ -191,7 +193,7 @@ Renderer::ThreadRun()
 // UI への描画通知を遅延させる時間を返す (即通知する場合は 0)。
 // UI に通知しない場合は -1 を返す。
 int64
-Renderer::DoRender(uint32 req)
+VideoRenderer::DoRender(uint32 req)
 {
 	// 1. REND_NORMAL なら電源オン時の通常描画指示、
 	//    REND_POWEROFF なら電源オン→オフ遷移時の描画指示。
@@ -305,7 +307,7 @@ Renderer::DoRender(uint32 req)
 
 #if defined(PERFREND)
 void
-Renderer::PrintPerf()
+VideoRenderer::PrintPerf()
 {
 	uint64 now = syncer->GetRealTime();
 	if (now - last_report_rtime < 5_sec) {
@@ -343,7 +345,7 @@ Renderer::PrintPerf()
 
 // スレッドの終了を指示
 void
-Renderer::Terminate()
+VideoRenderer::Terminate()
 {
 	std::lock_guard<std::mutex> lock(mtx);
 	request |= REQ_TERMINATE;
@@ -352,7 +354,7 @@ Renderer::Terminate()
 
 // リサイズ指示
 void
-Renderer::ResizeView(uint width_, uint height_)
+VideoRenderer::ResizeView(uint width_, uint height_)
 {
 	assert(enable);
 
@@ -366,14 +368,14 @@ Renderer::ResizeView(uint width_, uint height_)
 
 // 描画更新(通知)間隔を設定
 void
-Renderer::SetRefreshInterval(uint64 t)
+VideoRenderer::SetRefreshInterval(uint64 t)
 {
 	refresh_interval = t;
 }
 
 // モニタ更新
 void
-Renderer::MonitorUpdate(Monitor *, TextScreen& screen)
+VideoRenderer::MonitorUpdate(Monitor *, TextScreen& screen)
 {
 	int x;
 	int y;
@@ -418,7 +420,7 @@ Renderer::MonitorUpdate(Monitor *, TextScreen& screen)
 //
 
 // コンストラクタ
-X68030Renderer::X68030Renderer()
+X68030VideoRenderer::X68030VideoRenderer()
 {
 	// XXX とりあえず
 	width = 768;
@@ -428,13 +430,13 @@ X68030Renderer::X68030Renderer()
 }
 
 // デストラクタ
-X68030Renderer::~X68030Renderer()
+X68030VideoRenderer::~X68030VideoRenderer()
 {
 }
 
 // 初期化
 bool
-X68030Renderer::Init()
+X68030VideoRenderer::Init()
 {
 	if (inherited::Init() == false) {
 		return false;
@@ -447,7 +449,7 @@ X68030Renderer::Init()
 
 // 画面合成
 bool
-X68030Renderer::RenderMD()
+X68030VideoRenderer::RenderMD()
 {
 	bool updated = videoctlr->Render(bitmap);
 	return updated;
@@ -459,7 +461,7 @@ X68030Renderer::RenderMD()
 //
 
 // コンストラクタ
-LunaRenderer::LunaRenderer()
+LunaVideoRenderer::LunaVideoRenderer()
 {
 	width = 1280;
 	height = 1024;
@@ -468,13 +470,13 @@ LunaRenderer::LunaRenderer()
 }
 
 // デストラクタ
-LunaRenderer::~LunaRenderer()
+LunaVideoRenderer::~LunaVideoRenderer()
 {
 }
 
 // 初期化
 bool
-LunaRenderer::Init()
+LunaVideoRenderer::Init()
 {
 	if (inherited::Init() == false) {
 		return false;
@@ -487,7 +489,7 @@ LunaRenderer::Init()
 
 // 画面合成
 bool
-LunaRenderer::RenderMD()
+LunaVideoRenderer::RenderMD()
 {
 	bool updated = planevram->Render(bitmap);
 	return updated;
