@@ -11,7 +11,6 @@
 #pragma once
 
 #include "ethernet.h"
-#include "event.h"
 #include "hostnet.h"
 #include "message.h"
 
@@ -361,16 +360,16 @@ class RTL8019ASDevice : public EthernetDevice, public IHWAddrFilter
 
 	// 送信
 	void Transmit();
-	void TXEvent(Event&);
+	void TXEvent(Event *);
 	// 受信
 	void RxMessage(MessageID msgid, uint32 arg);
-	void RXEvent(Event&);
+	void RXEvent(Event *);
 	void RXHead();
-	void RXCopy(Event&, uint remain);
-	void RXDone(Event&);
+	void RXCopy(Event *, uint remain);
+	void RXDone(Event *);
 
-	void TXLedEvent(Event&);
-	void RXLedEvent(Event&);
+	void TXLedEvent(Event *);
+	void RXLedEvent(Event *);
 
 	void IncCounter(int n);
 
@@ -470,10 +469,10 @@ class RTL8019ASDevice : public EthernetDevice, public IHWAddrFilter
 
 	Monitor *monitor {};
 
-	Event tx_event { this };
-	Event rx_event { this };
-	Event txled_event { this };
-	Event rxled_event { this };
+	Event *tx_event {};
+	Event *rx_event {};
+	Event *txled_event {};
+	Event *rxled_event {};
 
 	InterruptDevice *interrupt {};
 
