@@ -10,6 +10,7 @@
 
 #define MPSCC_SIO_LOG_HACK
 #include "sio.h"
+#include "event.h"
 #include "hostcom.h"
 #include "keyboard.h"
 #include "mainapp.h"
@@ -47,14 +48,6 @@ SIODevice::SIODevice()
 	mpscc.chan[0].xc12_ns = 78.125_usec;
 	mpscc.chan[1].xc12_ns = 78.125_usec;
 
-	// LUNA では SIO と呼ぶほうが通りがいい。
-	// イベントの登録は親クラスで行ってある。
-	for (int ch = 0; ch < txevent.size(); ch++) {
-		auto& chan = mpscc.chan[ch];
-		txevent[ch].SetName(string_format("SIO Ch%c TX", chan.name));
-		rxevent[ch].SetName(string_format("SIO Ch%c RX", chan.name));
-	}
-
 	monitor = gMonitorManager->Regist(ID_MONITOR_SIO, this);
 	monitor->func = ToMonitorCallback(&SIODevice::MonitorUpdate);
 	monitor->SetSize(70, 24);
@@ -77,6 +70,14 @@ SIODevice::Init()
 
 	keyboard = GetKeyboard();
 
+	// LUNA では SIO と呼ぶほうが通りがいい。
+	// イベントの登録は親クラスで行ってある。
+	for (int ch = 0; ch < txevent.size(); ch++) {
+		auto& chan = mpscc.chan[ch];
+		txevent[ch]->SetName(string_format("SIO Ch%c TX", chan.name));
+		rxevent[ch]->SetName(string_format("SIO Ch%c RX", chan.name));
+	}
+
 	return true;
 }
 
