@@ -12,6 +12,7 @@
 // バイトアクセス時は HLB()、ワードアクセス時は HLW() マクロを使用のこと。
 
 #include "tvram.h"
+#include "event.h"
 #include "textscreen.h"
 #include "videoctlr.h"
 
@@ -53,8 +54,8 @@ TVRAMDevice::Init()
 
 	videoctlr = GetVideoCtlrDevice();
 
-	// 加工済みパレットを取得
-	palette = &(videoctlr->GetHostPalette())[0];
+	// 加工済みテキストパレットを取得。
+	palette = videoctlr->GetHostPalettePtr(256);
 
 	return true;
 }
