@@ -60,7 +60,7 @@ VideoCtlrDevice::Init()
 {
 	gvram = GetGVRAMDevice();
 	planevram = GetPlaneVRAMDevice();
-	renderer = GetRenderer();
+	renderer = GetVideoRenderer();
 	uimessage = gMainApp.GetUIMessage();
 
 	auto evman = GetEventManager();
@@ -489,7 +489,7 @@ VideoCtlrDevice::MakePalette()
 }
 
 // 画面の作成。CRTC から VDisp のタイミングで呼ばれる。
-// Renderer に作画指示を出すかどうかを決める。
+// VideoRenderer に作画指示を出すかどうかを決める。
 void
 VideoCtlrDevice::VDisp()
 {
