@@ -18,7 +18,7 @@
 
 class GVRAMDevice;
 class PlaneVRAMDevice;
-class Renderer;
+class VideoRenderer;
 class UIMessage;
 
 class VideoCtlr
@@ -182,8 +182,8 @@ class VideoCtlrDevice : public IODevice, public VideoCtlr
 
 	GVRAMDevice *gvram {};
 	PlaneVRAMDevice *planevram {};
-	Renderer *renderer {};
 	UIMessage *uimessage {};
+	VideoRenderer *renderer {};
 };
 
 static inline VideoCtlrDevice *GetVideoCtlrDevice() {
