@@ -65,7 +65,7 @@ WXMainView::WXMainView(wxWindow *parent)
 	SetName("WXMainView");
 
 	// デバイスを取得。
-	renderer = GetRenderer();
+	renderer = GetVideoRenderer();
 
 	// rich		dumb
 	// -------- -------
