@@ -23,7 +23,7 @@ class WXMonitorPanel : public WXTextScreen
 	~WXMonitorPanel() override;
 
 	// 画面を更新して再描画する。
-	void DoRefresh();
+	virtual void DoRefresh();
 
 	// 更新頻度設定
 	void SetRate(int hz);
@@ -63,12 +63,10 @@ class WXScrollMonitorWindow : public WXSubWindow
 	~WXScrollMonitorWindow() override;
 
 	void FontChanged() override;
-	void Fit() override;
 	bool Layout() override;
 
  private:
-	// 最大/最小サイズ設定
-	wxSize DoSizeHints();
+	bool GetMySizeHints(wxSize *, wxSize *, wxSize *, wxSize *) override;
 
 	// マウスホイールイベント
 	void OnMouseWheel(wxMouseEvent&);
@@ -84,10 +82,4 @@ class WXScrollMonitorWindow : public WXSubWindow
 
 	// スクロールバー
 	WXScrollBar *vscroll {};
-
-	// 前回のウィンドウマージン (クライアント領域の外側)
-	wxSize oldmargin {};
-
-	// 謎のリサイズ対策
-	bool layout_pass2 {};
 };
