@@ -36,19 +36,21 @@ class WXPalettePanel : public WXTextPanel
 	// ホストパレット
 	std::vector<Color> pal {};
 
-	// ゲストパレットを uint32 形式にしたもの。
-	// Bt454 なら $0000'0RGB、
-	// Bt458 なら $00RR'GGBB、
-	// X68030 なら $0000'WWWW (テキストパレット生データ)
-	std::vector<uint32> ipal {};
+	// ゲストパレット。
+	std::vector<uint16> vcpal {};	// X68030 のパレットレジスタ
+	std::vector<uint8> btpal {};	// Bt454/458 のパレット
 
 	// パレット欄の行数
 	int rows {};
 
 	// パレット領域の開始オフセット [px]
 	int pal0x {};
+	int pal1x {};					// X68030 の右列
 	int pal0y {};
 
+	// パレット番号に必要な16進桁数。
+	uint idxlen {};
+
 	// 現在指しているパレット
 	int cursor {};
 
