@@ -1281,7 +1281,7 @@ void
 WXStatusPanel::DClickPerf(const Indicator *ind)
 {
 	// モードを切り替える
-	syncer->RequestFullSpeed(!syncer->GetFullSpeed());
+	syncer->NotifyFullSpeed(!syncer->GetFullSpeed());
 }
 
 // コンテキストメニューイベント
