@@ -9,6 +9,7 @@
 //
 
 #include "wxversion.h"
+#include "hostnet.h"
 #include "monitor.h"
 #include <sys/utsname.h>
 
@@ -71,7 +72,7 @@ HostInfoMonitor::HostInfoMonitor()
 
 	// この時点で必要な情報は全部集めておく
 	int width = 0;
-	int height = 3;
+	int height = 4;
 
 	// OS 名
 	const auto info = wxPlatformInfo::Get();
@@ -170,6 +171,13 @@ HostInfoMonitor::HostInfoMonitor()
 	wxname = wxname + " (" + wxport + ")";
 	width = std::max(width, (int)wxname.Length());
 
+	// libslirp バージョン
+	slirpver = HostNetDevice::GetSlirpVersion();
+	if (slirpver == NULL) {
+		slirpver = "not compiled";
+	}
+	width = std::max(width, (int)strlen(slirpver));
+
 	monitor = gMonitorManager->Regist(ID_MONITOR_WXHOSTINFO, this);
 	monitor->func = ToMonitorCallback(&HostInfoMonitor::MonitorUpdate);
 	monitor->SetSize(11 + width, height);
@@ -213,4 +221,8 @@ HostInfoMonitor::MonitorUpdate(Monitor *, TextScreen& screen)
 	screen.Puts(0, y, "wxWidgets:");
 	screen.Puts(x, y, (const char *)wxname.mb_str());
 	y++;
+
+	screen.Puts(0, y, "libslirp:");
+	screen.Puts(x, y, slirpver);
+	y++;
 }
